from enum import Enum


class V1ChatCompletionsCreateResponse422Code(str, Enum):
    UNPROCESSABLEENTITYERROR = "UnprocessableEntityError"

    def __str__(self) -> str:
        return str(self.value)



from typing import Dict, List, Type

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from typing_extensions import Any, TypedDict, TypeVar

T = TypeVar("T", bound="FineTuningSample")


class FineTuningSampleDict(TypedDict):
    input_: str
    output: str
    pass


@_attrs_define
class FineTuningSample:
    """
    Attributes:
        input_ (str): The input text.
        output (str): The output text.
    """

    input_: str
    output: str

    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        input_ = self.input_

        output = self.output

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "input": input_,
                "output": output,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        input_ = d.pop("input")

        output = d.pop("output")

        fine_tuning_sample = cls(
            input_=input_,
            output=output,
        )

        fine_tuning_sample.additional_properties = d
        return fine_tuning_sample

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Dict, Union , List, Type, TypeVar
from attrs import define as _attrs_define
from attrs import field as _attrs_field
from typing_extensions import Any, Unpack
import re
import httpx
import json

from ...models.v1_chat_completions_create_json_body import V1ChatCompletionsCreateJsonBody
from ...models.v1_chat_completions_create_response_200 import V1ChatCompletionsCreateResponse200, V1ChatCompletionsCreateResponse200ChoicesItem
from ...models.v1_chat_completions_create_response_200_usage import V1ChatCompletionsCreateResponse200Usage
from ...types import UNSET, Unset

T = TypeVar("T", bound="V1ChatCompletionsCreateResponse200ChoicesItem")


def _get_kwargs(
    **body: Unpack[V1ChatCompletionsCreateJsonBody],
) -> Dict[str, Any]:
    headers: Dict[str, Any] = {}

    _kwargs: Dict[str, Any] = {
        "method": "post",
        "url": "/v1/chat/completions",
    }

    _json_body = body

    _kwargs["json"] = _json_body
    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def v1_chat_completions_create_wrapper(client):
    def v1_chat_completions_create_wrapped(
        **body: Unpack[V1ChatCompletionsCreateJsonBody],
    ) -> Union[V1ChatCompletionsCreateResponse200, V1ChatCompletionsCreateResponse200StreamContainer]:
        """Creates a model response for the given chat conversation.

        Args:
            body (V1ChatCompletionsCreateJsonBody):

        Raises:
            errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
            httpx.TimeoutException: If the request takes longer than Client.timeout.

        Returns:
            Union[V1ChatCompletionsCreateResponse200, V1ChatCompletionsCreateResponse200StreamContainer]
        """
        kwargs = _get_kwargs(
            **body,
        )
        httpx_client = client.get_httpx_client()
        if ('stream' in body) and (body['stream']):
            stream = httpx_client.stream(**kwargs)
            return V1ChatCompletionsCreateResponse200StreamContainer(stream)
        else:
            response = httpx_client.request(
                **kwargs,
            )
            return V1ChatCompletionsCreateResponse200.from_dict(response.json())
    return v1_chat_completions_create_wrapped


END_STREAM = 'done'
class V1ChatCompletionsCreateResponse200StreamContainer:
    _pattern = '(?<={key}: )(.*)'
    trace_id: str = None

    def __init__(self, stream: httpx.Response):  
        self._stream = stream

    def _parse_data(self, text: str):
        match = re.search(self._pattern.format(key='data'), text)
        if match:
            data = json.loads(match.group(1))
            parsed_data: V1ChatCompletionsCreateResponse200Stream = V1ChatCompletionsCreateResponse200Stream.from_dict(data)
            return parsed_data
        else:   return None

    def _parse_event(self, text: str):
        match = re.search(self._pattern.format(key='event'), text)
        if match: return match.group(1)
        else:   return None

    def _parse_trace_id(self, text: str):
        match = re.search(self._pattern.format(key='trace_id'), text)
        if match: return match.group(1)
        else:   return None
    
    def __iter__(self):
        def generator():
            with self._stream as stream:
                for text in stream.iter_text():
                    event = self._parse_event(text)
                    self.trace_id = self._parse_trace_id(text)
                    if event == END_STREAM:
                        break
                    data = self._parse_data(text)

                    yield data
        return generator()
    

@_attrs_define
class V1ChatCompletionsCreateResponse200Stream:
    """
    Attributes:
        id (str): A unique identifier for the chat completion. Each chunk has the same ID.
        choices (List['V1ChatCompletionsCreateResponse200ChoicesItem']): A list of chat completion choices. Can be more
            than one if n is greater than 1.
        created (int): The Unix timestamp (in seconds) of when the chat completion was created. Each chunk has the same
            timestamp.
        model (str): The model to generate the completion.
        provider_name (str): The name of the provider that generated the completion.
        provider_id (str): The ID of the provider that generated the completion.
        usage (Union[Unset, V1ChatCompletionsCreateResponse200Usage]): The usage statistics for the completion.
    """

    id: str
    choices: List["V1ChatCompletionsCreateResponse200ChoicesItemStream"]
    created: int
    model: str
    usage: Union[Unset, "V1ChatCompletionsCreateResponse200Usage"] = UNSET

    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        id = self.id

        choices = []
        for choices_item_data in self.choices:
            choices_item = choices_item_data.to_dict()
            choices.append(choices_item)

        created = self.created

        model = self.model
        

        usage: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.usage, Unset):
            usage = self.usage.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "id": id,
                "choices": choices,
                "created": created,
                "model": model,
            }
        )
        if usage is not UNSET:
            field_dict["usage"] = usage

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:

        d = src_dict.copy()
        id = d.pop("id")

        choices = []
        _choices = d.pop("choices")
        for choices_item_data in _choices:
            choices_item = V1ChatCompletionsCreateResponse200ChoicesItemStream.from_dict(choices_item_data)

            choices.append(choices_item)

        created = d.pop("created")

        model = d.pop("model")

        _usage = d.pop("usage", UNSET)
        usage: Union[Unset, V1ChatCompletionsCreateResponse200Usage]
        if isinstance(_usage, Unset):
            usage = UNSET
        else:
            usage = V1ChatCompletionsCreateResponse200Usage.from_dict(_usage)

        v1_chat_completions_create_response_200 = cls(
            id=id,
            choices=choices,
            created=created,
            model=model,
            usage=usage,
        )

        v1_chat_completions_create_response_200.additional_properties = d
        return v1_chat_completions_create_response_200

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties


@_attrs_define
class V1ChatCompletionsCreateResponse200ChoicesItemStream:
    """
    Attributes:
        message (str): The generated message in the chat completion choice.
        finish_reason (str): The reason the chat completion finished, e.g., 'stop' or 'length'.
    """

    delta: str
    finish_reason: str

    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        delta = self.delta

        finish_reason = self.finish_reason

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "delta": delta,
                "finish_reason": finish_reason,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        delta = d.pop("delta")

        finish_reason = d.pop("finish_reason")

        v1_chat_completions_create_response_200_choices_item = cls(
            delta=delta,
            finish_reason=finish_reason,
        )

        v1_chat_completions_create_response_200_choices_item.additional_properties = d
        return v1_chat_completions_create_response_200_choices_item

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties


""" Contains methods for accessing the API """


from typing_extensions import Unpack

from ..models import (
    ApiProjectsDataPointsCreateJsonBodyDict,
    ApiProjectsDataPointsPartialUpdateJsonBodyDict,
    ApiProjectsDataPointsUpdateJsonBodyDict,
    ApiProjectsTracesCreateJsonBodyDict,
    AuthTokenCreateDataBodyDict,
    V1ChatCompletionsCreateJsonBodyDict,
    V1EmbeddingsCreateJsonBodyDict,
    V1FinetuningCreateJsonBodyDict,
)
from ..models.api_schema_retrieve_format import ApiSchemaRetrieveFormat
from ..models.api_schema_retrieve_lang import ApiSchemaRetrieveLang
from .api.api_schema_retrieve import api_schema_retrieve_wrapper
from .auth_token.auth_token_create import auth_token_create_wrapper
from .chat_completions.v1_chat_completions_create import v1_chat_completions_create_wrapper
from .datapoints.api_projects_data_points_create import api_projects_data_points_create_wrapper
from .datapoints.api_projects_data_points_destroy import api_projects_data_points_destroy_wrapper
from .datapoints.api_projects_data_points_list import api_projects_data_points_list_wrapper
from .datapoints.api_projects_data_points_partial_update import api_projects_data_points_partial_update_wrapper
from .datapoints.api_projects_data_points_retrieve import api_projects_data_points_retrieve_wrapper
from .datapoints.api_projects_data_points_update import api_projects_data_points_update_wrapper
from .embeddings.v1_embeddings_create import v1_embeddings_create_wrapper
from .finetuning.v1_finetuning_create import v1_finetuning_create_wrapper
from .finetuning.v1_finetuning_retrieve import v1_finetuning_retrieve_wrapper
from .playgrounds.api_playgrounds_image_retrieve import api_playgrounds_image_retrieve_wrapper
from .playgrounds.api_playgrounds_ot_info_retrieve import api_playgrounds_ot_info_retrieve_wrapper
from .providers.api_providers_leaderboard_retrieve import api_providers_leaderboard_retrieve_wrapper
from .providers.api_providers_retrieve import api_providers_retrieve_wrapper
from .traces.api_projects_traces_create import api_projects_traces_create_wrapper


class PlaygroundsModule:
    def __init__(self, client):
        self._client = client

    def retrieve_image(
        self,
        sharable_playground_uuid: str,
    ):
        return api_playgrounds_image_retrieve_wrapper(self._client)(
            sharable_playground_uuid,
        )

    def retrieve_ot_info(
        self,
        sharable_playground_uuid: str,
    ):
        return api_playgrounds_ot_info_retrieve_wrapper(self._client)(
            sharable_playground_uuid,
        )


class DatapointsModule:
    def __init__(self, client):
        self._client = client

    def list(
        self,
    ):
        return api_projects_data_points_list_wrapper(self._client)()

    def create(self, **kwargs: Unpack[ApiProjectsDataPointsCreateJsonBodyDict]):
        return api_projects_data_points_create_wrapper(self._client)(**kwargs)

    def retrieve(
        self,
        id: int,
    ):
        return api_projects_data_points_retrieve_wrapper(self._client)(
            id,
        )

    def update(self, id: int, **kwargs: Unpack[ApiProjectsDataPointsUpdateJsonBodyDict]):
        return api_projects_data_points_update_wrapper(self._client)(id, **kwargs)

    def delete(
        self,
        id: int,
    ):
        return api_projects_data_points_destroy_wrapper(self._client)(
            id,
        )

    def patch(
        self, id: int, **kwargs: Unpack[ApiProjectsDataPointsPartialUpdateJsonBodyDict]
    ):
        return api_projects_data_points_partial_update_wrapper(self._client)(id, **kwargs)


class TracesModule:
    def __init__(self, client):
        self._client = client

    def create(self, **kwargs: Unpack[ApiProjectsTracesCreateJsonBodyDict]):
        return api_projects_traces_create_wrapper(self._client)(**kwargs)


class ProvidersModule:
    def __init__(self, client):
        self._client = client

    def retrieve_providers(
        self,
        days: int = None,
    ):
        return api_providers_retrieve_wrapper(self._client)(
            days,
        )

    def retrieve_leaderboard(
        self,
        days: int = None,
    ):
        return api_providers_leaderboard_retrieve_wrapper(self._client)(
            days,
        )


class ApiModule:
    def __init__(self, client):
        self._client = client

    def retrieve(
        self,
        format: ApiSchemaRetrieveFormat = None,
        lang: ApiSchemaRetrieveLang = None,
    ):
        return api_schema_retrieve_wrapper(self._client)(
            format,
            lang,
        )


class AuthTokenModule:
    def __init__(self, client):
        self._client = client

    def create(self, **kwargs: Unpack[AuthTokenCreateDataBodyDict]):
        return auth_token_create_wrapper(self._client)(**kwargs)


class ChatCompletionsModule:
    def __init__(self, client):
        self._client = client

    def create(self, **kwargs: Unpack[V1ChatCompletionsCreateJsonBodyDict]):
        return v1_chat_completions_create_wrapper(self._client)(**kwargs)


class EmbeddingsModule:
    def __init__(self, client):
        self._client = client

    def create(self, **kwargs: Unpack[V1EmbeddingsCreateJsonBodyDict]):
        return v1_embeddings_create_wrapper(self._client)(**kwargs)


class FinetuningModule:
    def __init__(self, client):
        self._client = client

    def create(self, **kwargs: Unpack[V1FinetuningCreateJsonBodyDict]):
        return v1_finetuning_create_wrapper(self._client)(**kwargs)

    def retrieve(
        self,
        job_id: str,
    ):
        return v1_finetuning_retrieve_wrapper(self._client)(
            job_id,
        )


class AuthModuleWrapper:
    token: AuthTokenModule

    def __init__(self, client):
        self.token = AuthTokenModule(client)


class ChatModuleWrapper:
    completions: ChatCompletionsModule

    def __init__(self, client):
        self.completions = ChatCompletionsModule(client)



from typing import Dict, List, Type

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from typing_extensions import Any, TypedDict, TypeVar

from ..models.api_providers_leaderboard_retrieve_response_200_leaderboard_item import (
    ApiProvidersLeaderboardRetrieveResponse200LeaderboardItem,
)

T = TypeVar("T", bound="ApiProvidersLeaderboardRetrieveResponse200")


class ApiProvidersLeaderboardRetrieveResponse200Dict(TypedDict):
    days: int
    leaderboard: List["ApiProvidersLeaderboardRetrieveResponse200LeaderboardItem"]
    pass


@_attrs_define
class ApiProvidersLeaderboardRetrieveResponse200:
    """
    Attributes:
        days (int):
        leaderboard (List['ApiProvidersLeaderboardRetrieveResponse200LeaderboardItem']):
    """

    days: int
    leaderboard: List["ApiProvidersLeaderboardRetrieveResponse200LeaderboardItem"]

    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        days = self.days

        leaderboard = []
        for leaderboard_item_data in self.leaderboard:
            leaderboard_item = leaderboard_item_data.to_dict()
            leaderboard.append(leaderboard_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "days": days,
                "leaderboard": leaderboard,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.api_providers_leaderboard_retrieve_response_200_leaderboard_item import (
            ApiProvidersLeaderboardRetrieveResponse200LeaderboardItem,
        )

        d = src_dict.copy()
        days = d.pop("days")

        leaderboard = []
        _leaderboard = d.pop("leaderboard")
        for leaderboard_item_data in _leaderboard:
            leaderboard_item = ApiProvidersLeaderboardRetrieveResponse200LeaderboardItem.from_dict(
                leaderboard_item_data
            )

            leaderboard.append(leaderboard_item)

        api_providers_leaderboard_retrieve_response_200 = cls(
            days=days,
            leaderboard=leaderboard,
        )

        api_providers_leaderboard_retrieve_response_200.additional_properties = d
        return api_providers_leaderboard_retrieve_response_200

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



""" Contains all the data models used in inputs/outputs """

from .api_projects_data_points_create_data_body import (
    ApiProjectsDataPointsCreateDataBody,
    ApiProjectsDataPointsCreateDataBodyDict,
)
from .api_projects_data_points_create_files_body import (
    ApiProjectsDataPointsCreateFilesBody,
    ApiProjectsDataPointsCreateFilesBodyDict,
)
from .api_projects_data_points_create_json_body import (
    ApiProjectsDataPointsCreateJsonBody,
    ApiProjectsDataPointsCreateJsonBodyDict,
)
from .api_projects_data_points_create_response_201 import ApiProjectsDataPointsCreateResponse201
from .api_projects_data_points_list_response_200_item import ApiProjectsDataPointsListResponse200Item
from .api_projects_data_points_partial_update_data_body import (
    ApiProjectsDataPointsPartialUpdateDataBody,
    ApiProjectsDataPointsPartialUpdateDataBodyDict,
)
from .api_projects_data_points_partial_update_files_body import (
    ApiProjectsDataPointsPartialUpdateFilesBody,
    ApiProjectsDataPointsPartialUpdateFilesBodyDict,
)
from .api_projects_data_points_partial_update_json_body import (
    ApiProjectsDataPointsPartialUpdateJsonBody,
    ApiProjectsDataPointsPartialUpdateJsonBodyDict,
)
from .api_projects_data_points_partial_update_response_200 import ApiProjectsDataPointsPartialUpdateResponse200
from .api_projects_data_points_retrieve_response_200 import ApiProjectsDataPointsRetrieveResponse200
from .api_projects_data_points_update_data_body import (
    ApiProjectsDataPointsUpdateDataBody,
    ApiProjectsDataPointsUpdateDataBodyDict,
)
from .api_projects_data_points_update_files_body import (
    ApiProjectsDataPointsUpdateFilesBody,
    ApiProjectsDataPointsUpdateFilesBodyDict,
)
from .api_projects_data_points_update_json_body import (
    ApiProjectsDataPointsUpdateJsonBody,
    ApiProjectsDataPointsUpdateJsonBodyDict,
)
from .api_projects_data_points_update_response_200 import ApiProjectsDataPointsUpdateResponse200
from .api_projects_traces_create_data_body import ApiProjectsTracesCreateDataBody, ApiProjectsTracesCreateDataBodyDict
from .api_projects_traces_create_data_body_raw_request_type_0 import ApiProjectsTracesCreateDataBodyRawRequestType0
from .api_projects_traces_create_data_body_raw_response_type_0 import ApiProjectsTracesCreateDataBodyRawResponseType0
from .api_projects_traces_create_files_body import (
    ApiProjectsTracesCreateFilesBody,
    ApiProjectsTracesCreateFilesBodyDict,
)
from .api_projects_traces_create_files_body_raw_request_type_0 import ApiProjectsTracesCreateFilesBodyRawRequestType0
from .api_projects_traces_create_files_body_raw_response_type_0 import ApiProjectsTracesCreateFilesBodyRawResponseType0
from .api_projects_traces_create_json_body import ApiProjectsTracesCreateJsonBody, ApiProjectsTracesCreateJsonBodyDict
from .api_projects_traces_create_json_body_raw_request_type_0 import ApiProjectsTracesCreateJsonBodyRawRequestType0
from .api_projects_traces_create_json_body_raw_response_type_0 import ApiProjectsTracesCreateJsonBodyRawResponseType0
from .api_projects_traces_create_response_201 import ApiProjectsTracesCreateResponse201
from .api_projects_traces_create_response_201_raw_request_type_0 import (
    ApiProjectsTracesCreateResponse201RawRequestType0,
)
from .api_projects_traces_create_response_201_raw_response_type_0 import (
    ApiProjectsTracesCreateResponse201RawResponseType0,
)
from .api_providers_leaderboard_retrieve_response_200 import ApiProvidersLeaderboardRetrieveResponse200
from .api_providers_leaderboard_retrieve_response_200_leaderboard_item import (
    ApiProvidersLeaderboardRetrieveResponse200LeaderboardItem,
)
from .api_response_validation_error import APIResponseValidationError
from .api_response_validation_error_code import APIResponseValidationErrorCode
from .api_response_validation_error_code_enum import APIResponseValidationErrorCodeEnum
from .api_schema_retrieve_format import ApiSchemaRetrieveFormat
from .api_schema_retrieve_lang import ApiSchemaRetrieveLang
from .api_schema_retrieve_response_200 import ApiSchemaRetrieveResponse200
from .auth_token import AuthToken
from .auth_token_create_data_body import AuthTokenCreateDataBody, AuthTokenCreateDataBodyDict
from .auth_token_create_files_body import AuthTokenCreateFilesBody, AuthTokenCreateFilesBodyDict
from .auth_token_create_json_body import AuthTokenCreateJsonBody, AuthTokenCreateJsonBodyDict
from .auth_token_create_response_200 import AuthTokenCreateResponse200
from .authentication_error import AuthenticationError
from .authentication_error_code import AuthenticationErrorCode
from .authentication_error_code_enum import AuthenticationErrorCodeEnum
from .catch_all_error import CatchAllError
from .catch_all_error_code import CatchAllErrorCode
from .catch_all_error_code_enum import CatchAllErrorCodeEnum
from .chat_completion_input import ChatCompletionInput
from .chat_completion_input_logit_bias_type_0 import ChatCompletionInputLogitBiasType0
from .chat_completion_input_messages_item import ChatCompletionInputMessagesItem
from .chat_completion_input_messages_item_role import ChatCompletionInputMessagesItemRole
from .chat_completion_input_response_format_type_0 import ChatCompletionInputResponseFormatType0
from .chat_completion_input_tools_item import ChatCompletionInputToolsItem
from .chat_completion_response import ChatCompletionResponse
from .chat_completion_response_choices_item import ChatCompletionResponseChoicesItem
from .chat_completion_response_usage import ChatCompletionResponseUsage
from .conflict_error import ConflictError
from .conflict_error_code import ConflictErrorCode
from .conflict_error_code_enum import ConflictErrorCodeEnum
from .data_point import DataPoint
from .embedding import Embedding
from .embeddings_input import EmbeddingsInput
from .embeddings_input_encoding_format import EmbeddingsInputEncodingFormat
from .embeddings_response import EmbeddingsResponse
from .embeddings_response_data_item import EmbeddingsResponseDataItem
from .embeddings_response_usage import EmbeddingsResponseUsage
from .encoding_format_enum import EncodingFormatEnum
from .fine_tuning_input import FineTuningInput
from .fine_tuning_input_training_data_item import FineTuningInputTrainingDataItem
from .fine_tuning_input_validaton_data_item import FineTuningInputValidatonDataItem
from .fine_tuning_response import FineTuningResponse
from .fine_tuning_sample import FineTuningSample
from .input_data_point import InputDataPoint
from .internal_server_error_type_0 import InternalServerErrorType0
from .internal_server_error_type_0_code import InternalServerErrorType0Code
from .internal_server_error_type_1 import InternalServerErrorType1
from .internal_server_error_type_1_code import InternalServerErrorType1Code
from .internal_server_error_type_2 import InternalServerErrorType2
from .internal_server_error_type_2_code import InternalServerErrorType2Code
from .internal_server_error_type_3 import InternalServerErrorType3
from .internal_server_error_type_3_code import InternalServerErrorType3Code
from .internal_server_error_type_4 import InternalServerErrorType4
from .internal_server_error_type_4_code import InternalServerErrorType4Code
from .internal_server_error_type_5 import InternalServerErrorType5
from .internal_server_error_type_5_code import InternalServerErrorType5Code
from .leaderboard_item import LeaderboardItem
from .leaderboard_response import LeaderboardResponse
from .leaderboard_response_leaderboard_item import LeaderboardResponseLeaderboardItem
from .message import Message
from .message_role import MessageRole
from .model_not_found_error import ModelNotFoundError
from .model_not_found_error_code import ModelNotFoundErrorCode
from .model_not_found_error_code_enum import ModelNotFoundErrorCodeEnum
from .not_found_error_type_0 import NotFoundErrorType0
from .not_found_error_type_0_code import NotFoundErrorType0Code
from .not_found_error_type_1 import NotFoundErrorType1
from .not_found_error_type_1_code import NotFoundErrorType1Code
from .patched_data_point import PatchedDataPoint
from .permission_denied_error import PermissionDeniedError
from .permission_denied_error_code import PermissionDeniedErrorCode
from .permission_denied_error_code_enum import PermissionDeniedErrorCodeEnum
from .provider_api_connection_error import ProviderAPIConnectionError
from .provider_api_connection_error_code import ProviderAPIConnectionErrorCode
from .provider_api_connection_error_code_enum import ProviderAPIConnectionErrorCodeEnum
from .provider_api_status_error import ProviderAPIStatusError
from .provider_api_status_error_code import ProviderAPIStatusErrorCode
from .provider_api_status_error_code_enum import ProviderAPIStatusErrorCodeEnum
from .provider_api_timeout_error import ProviderAPITimeoutError
from .provider_api_timeout_error_code import ProviderAPITimeoutErrorCode
from .provider_api_timeout_error_code_enum import ProviderAPITimeoutErrorCodeEnum
from .provider_internal_server_error import ProviderInternalServerError
from .provider_internal_server_error_code import ProviderInternalServerErrorCode
from .provider_internal_server_error_code_enum import ProviderInternalServerErrorCodeEnum
from .provider_not_found_error import ProviderNotFoundError
from .provider_not_found_error_code import ProviderNotFoundErrorCode
from .provider_not_found_error_code_enum import ProviderNotFoundErrorCodeEnum
from .rate_limit_error import RateLimitError
from .rate_limit_error_code import RateLimitErrorCode
from .rate_limit_error_code_enum import RateLimitErrorCodeEnum
from .response_choice import ResponseChoice
from .retrieve_fine_tuning_response import RetrieveFineTuningResponse
from .role_enum import RoleEnum
from .trace import Trace
from .trace_raw_request_type_0 import TraceRawRequestType0
from .trace_raw_response_type_0 import TraceRawResponseType0
from .unprocessable_entity_error import UnprocessableEntityError
from .unprocessable_entity_error_code import UnprocessableEntityErrorCode
from .unprocessable_entity_error_code_enum import UnprocessableEntityErrorCodeEnum
from .usage import Usage
from .v1_chat_completions_create_data_body import V1ChatCompletionsCreateDataBody, V1ChatCompletionsCreateDataBodyDict
from .v1_chat_completions_create_data_body_logit_bias_type_0 import V1ChatCompletionsCreateDataBodyLogitBiasType0
from .v1_chat_completions_create_data_body_messages_item import V1ChatCompletionsCreateDataBodyMessagesItem
from .v1_chat_completions_create_data_body_messages_item_role import V1ChatCompletionsCreateDataBodyMessagesItemRole
from .v1_chat_completions_create_data_body_response_format_type_0 import (
    V1ChatCompletionsCreateDataBodyResponseFormatType0,
)
from .v1_chat_completions_create_data_body_tools_item import V1ChatCompletionsCreateDataBodyToolsItem
from .v1_chat_completions_create_files_body import (
    V1ChatCompletionsCreateFilesBody,
    V1ChatCompletionsCreateFilesBodyDict,
)
from .v1_chat_completions_create_files_body_logit_bias_type_0 import V1ChatCompletionsCreateFilesBodyLogitBiasType0
from .v1_chat_completions_create_files_body_messages_item import V1ChatCompletionsCreateFilesBodyMessagesItem
from .v1_chat_completions_create_files_body_messages_item_role import V1ChatCompletionsCreateFilesBodyMessagesItemRole
from .v1_chat_completions_create_files_body_response_format_type_0 import (
    V1ChatCompletionsCreateFilesBodyResponseFormatType0,
)
from .v1_chat_completions_create_files_body_tools_item import V1ChatCompletionsCreateFilesBodyToolsItem
from .v1_chat_completions_create_json_body import V1ChatCompletionsCreateJsonBody, V1ChatCompletionsCreateJsonBodyDict
from .v1_chat_completions_create_json_body_logit_bias_type_0 import V1ChatCompletionsCreateJsonBodyLogitBiasType0
from .v1_chat_completions_create_json_body_messages_item import V1ChatCompletionsCreateJsonBodyMessagesItem
from .v1_chat_completions_create_json_body_messages_item_role import V1ChatCompletionsCreateJsonBodyMessagesItemRole
from .v1_chat_completions_create_json_body_response_format_type_0 import (
    V1ChatCompletionsCreateJsonBodyResponseFormatType0,
)
from .v1_chat_completions_create_json_body_tools_item import V1ChatCompletionsCreateJsonBodyToolsItem
from .v1_chat_completions_create_response_200 import V1ChatCompletionsCreateResponse200
from .v1_chat_completions_create_response_200_choices_item import V1ChatCompletionsCreateResponse200ChoicesItem
from .v1_chat_completions_create_response_200_usage import V1ChatCompletionsCreateResponse200Usage
from .v1_chat_completions_create_response_400 import V1ChatCompletionsCreateResponse400
from .v1_chat_completions_create_response_400_code import V1ChatCompletionsCreateResponse400Code
from .v1_chat_completions_create_response_400_details import V1ChatCompletionsCreateResponse400Details
from .v1_chat_completions_create_response_400_details_additional_property import (
    V1ChatCompletionsCreateResponse400DetailsAdditionalProperty,
)
from .v1_chat_completions_create_response_400_details_additional_property_error_messages_item import (
    V1ChatCompletionsCreateResponse400DetailsAdditionalPropertyErrorMessagesItem,
)
from .v1_chat_completions_create_response_401 import V1ChatCompletionsCreateResponse401
from .v1_chat_completions_create_response_401_code import V1ChatCompletionsCreateResponse401Code
from .v1_chat_completions_create_response_403 import V1ChatCompletionsCreateResponse403
from .v1_chat_completions_create_response_403_code import V1ChatCompletionsCreateResponse403Code
from .v1_chat_completions_create_response_404_type_0 import V1ChatCompletionsCreateResponse404Type0
from .v1_chat_completions_create_response_404_type_0_code import V1ChatCompletionsCreateResponse404Type0Code
from .v1_chat_completions_create_response_404_type_1 import V1ChatCompletionsCreateResponse404Type1
from .v1_chat_completions_create_response_404_type_1_code import V1ChatCompletionsCreateResponse404Type1Code
from .v1_chat_completions_create_response_409 import V1ChatCompletionsCreateResponse409
from .v1_chat_completions_create_response_409_code import V1ChatCompletionsCreateResponse409Code
from .v1_chat_completions_create_response_422 import V1ChatCompletionsCreateResponse422
from .v1_chat_completions_create_response_422_code import V1ChatCompletionsCreateResponse422Code
from .v1_chat_completions_create_response_429 import V1ChatCompletionsCreateResponse429
from .v1_chat_completions_create_response_429_code import V1ChatCompletionsCreateResponse429Code
from .v1_chat_completions_create_response_500_type_0 import V1ChatCompletionsCreateResponse500Type0
from .v1_chat_completions_create_response_500_type_0_code import V1ChatCompletionsCreateResponse500Type0Code
from .v1_chat_completions_create_response_500_type_1 import V1ChatCompletionsCreateResponse500Type1
from .v1_chat_completions_create_response_500_type_1_code import V1ChatCompletionsCreateResponse500Type1Code
from .v1_chat_completions_create_response_500_type_2 import V1ChatCompletionsCreateResponse500Type2
from .v1_chat_completions_create_response_500_type_2_code import V1ChatCompletionsCreateResponse500Type2Code
from .v1_chat_completions_create_response_500_type_3 import V1ChatCompletionsCreateResponse500Type3
from .v1_chat_completions_create_response_500_type_3_code import V1ChatCompletionsCreateResponse500Type3Code
from .v1_chat_completions_create_response_500_type_4 import V1ChatCompletionsCreateResponse500Type4
from .v1_chat_completions_create_response_500_type_4_code import V1ChatCompletionsCreateResponse500Type4Code
from .v1_chat_completions_create_response_500_type_5 import V1ChatCompletionsCreateResponse500Type5
from .v1_chat_completions_create_response_500_type_5_code import V1ChatCompletionsCreateResponse500Type5Code
from .v1_embeddings_create_data_body import V1EmbeddingsCreateDataBody, V1EmbeddingsCreateDataBodyDict
from .v1_embeddings_create_data_body_encoding_format import V1EmbeddingsCreateDataBodyEncodingFormat
from .v1_embeddings_create_files_body import V1EmbeddingsCreateFilesBody, V1EmbeddingsCreateFilesBodyDict
from .v1_embeddings_create_files_body_encoding_format import V1EmbeddingsCreateFilesBodyEncodingFormat
from .v1_embeddings_create_json_body import V1EmbeddingsCreateJsonBody, V1EmbeddingsCreateJsonBodyDict
from .v1_embeddings_create_json_body_encoding_format import V1EmbeddingsCreateJsonBodyEncodingFormat
from .v1_embeddings_create_response_200 import V1EmbeddingsCreateResponse200
from .v1_embeddings_create_response_200_data_item import V1EmbeddingsCreateResponse200DataItem
from .v1_embeddings_create_response_200_usage import V1EmbeddingsCreateResponse200Usage
from .v1_embeddings_create_response_400 import V1EmbeddingsCreateResponse400
from .v1_embeddings_create_response_400_code import V1EmbeddingsCreateResponse400Code
from .v1_embeddings_create_response_400_details import V1EmbeddingsCreateResponse400Details
from .v1_embeddings_create_response_400_details_additional_property import (
    V1EmbeddingsCreateResponse400DetailsAdditionalProperty,
)
from .v1_embeddings_create_response_400_details_additional_property_error_messages_item import (
    V1EmbeddingsCreateResponse400DetailsAdditionalPropertyErrorMessagesItem,
)
from .v1_embeddings_create_response_401 import V1EmbeddingsCreateResponse401
from .v1_embeddings_create_response_401_code import V1EmbeddingsCreateResponse401Code
from .v1_embeddings_create_response_403 import V1EmbeddingsCreateResponse403
from .v1_embeddings_create_response_403_code import V1EmbeddingsCreateResponse403Code
from .v1_embeddings_create_response_404_type_0 import V1EmbeddingsCreateResponse404Type0
from .v1_embeddings_create_response_404_type_0_code import V1EmbeddingsCreateResponse404Type0Code
from .v1_embeddings_create_response_404_type_1 import V1EmbeddingsCreateResponse404Type1
from .v1_embeddings_create_response_404_type_1_code import V1EmbeddingsCreateResponse404Type1Code
from .v1_embeddings_create_response_409 import V1EmbeddingsCreateResponse409
from .v1_embeddings_create_response_409_code import V1EmbeddingsCreateResponse409Code
from .v1_embeddings_create_response_422 import V1EmbeddingsCreateResponse422
from .v1_embeddings_create_response_422_code import V1EmbeddingsCreateResponse422Code
from .v1_embeddings_create_response_429 import V1EmbeddingsCreateResponse429
from .v1_embeddings_create_response_429_code import V1EmbeddingsCreateResponse429Code
from .v1_embeddings_create_response_500_type_0 import V1EmbeddingsCreateResponse500Type0
from .v1_embeddings_create_response_500_type_0_code import V1EmbeddingsCreateResponse500Type0Code
from .v1_embeddings_create_response_500_type_1 import V1EmbeddingsCreateResponse500Type1
from .v1_embeddings_create_response_500_type_1_code import V1EmbeddingsCreateResponse500Type1Code
from .v1_embeddings_create_response_500_type_2 import V1EmbeddingsCreateResponse500Type2
from .v1_embeddings_create_response_500_type_2_code import V1EmbeddingsCreateResponse500Type2Code
from .v1_embeddings_create_response_500_type_3 import V1EmbeddingsCreateResponse500Type3
from .v1_embeddings_create_response_500_type_3_code import V1EmbeddingsCreateResponse500Type3Code
from .v1_embeddings_create_response_500_type_4 import V1EmbeddingsCreateResponse500Type4
from .v1_embeddings_create_response_500_type_4_code import V1EmbeddingsCreateResponse500Type4Code
from .v1_embeddings_create_response_500_type_5 import V1EmbeddingsCreateResponse500Type5
from .v1_embeddings_create_response_500_type_5_code import V1EmbeddingsCreateResponse500Type5Code
from .v1_finetuning_create_data_body import V1FinetuningCreateDataBody, V1FinetuningCreateDataBodyDict
from .v1_finetuning_create_data_body_training_data_item import V1FinetuningCreateDataBodyTrainingDataItem
from .v1_finetuning_create_data_body_validaton_data_item import V1FinetuningCreateDataBodyValidatonDataItem
from .v1_finetuning_create_files_body import V1FinetuningCreateFilesBody, V1FinetuningCreateFilesBodyDict
from .v1_finetuning_create_files_body_training_data_item import V1FinetuningCreateFilesBodyTrainingDataItem
from .v1_finetuning_create_files_body_validaton_data_item import V1FinetuningCreateFilesBodyValidatonDataItem
from .v1_finetuning_create_json_body import V1FinetuningCreateJsonBody, V1FinetuningCreateJsonBodyDict
from .v1_finetuning_create_json_body_training_data_item import V1FinetuningCreateJsonBodyTrainingDataItem
from .v1_finetuning_create_json_body_validaton_data_item import V1FinetuningCreateJsonBodyValidatonDataItem
from .v1_finetuning_create_response_200 import V1FinetuningCreateResponse200
from .v1_finetuning_create_response_400 import V1FinetuningCreateResponse400
from .v1_finetuning_create_response_400_code import V1FinetuningCreateResponse400Code
from .v1_finetuning_create_response_400_details import V1FinetuningCreateResponse400Details
from .v1_finetuning_create_response_400_details_additional_property import (
    V1FinetuningCreateResponse400DetailsAdditionalProperty,
)
from .v1_finetuning_create_response_400_details_additional_property_error_messages_item import (
    V1FinetuningCreateResponse400DetailsAdditionalPropertyErrorMessagesItem,
)
from .v1_finetuning_create_response_401 import V1FinetuningCreateResponse401
from .v1_finetuning_create_response_401_code import V1FinetuningCreateResponse401Code
from .v1_finetuning_create_response_403 import V1FinetuningCreateResponse403
from .v1_finetuning_create_response_403_code import V1FinetuningCreateResponse403Code
from .v1_finetuning_create_response_404_type_0 import V1FinetuningCreateResponse404Type0
from .v1_finetuning_create_response_404_type_0_code import V1FinetuningCreateResponse404Type0Code
from .v1_finetuning_create_response_404_type_1 import V1FinetuningCreateResponse404Type1
from .v1_finetuning_create_response_404_type_1_code import V1FinetuningCreateResponse404Type1Code
from .v1_finetuning_create_response_409 import V1FinetuningCreateResponse409
from .v1_finetuning_create_response_409_code import V1FinetuningCreateResponse409Code
from .v1_finetuning_create_response_422 import V1FinetuningCreateResponse422
from .v1_finetuning_create_response_422_code import V1FinetuningCreateResponse422Code
from .v1_finetuning_create_response_429 import V1FinetuningCreateResponse429
from .v1_finetuning_create_response_429_code import V1FinetuningCreateResponse429Code
from .v1_finetuning_create_response_500_type_0 import V1FinetuningCreateResponse500Type0
from .v1_finetuning_create_response_500_type_0_code import V1FinetuningCreateResponse500Type0Code
from .v1_finetuning_create_response_500_type_1 import V1FinetuningCreateResponse500Type1
from .v1_finetuning_create_response_500_type_1_code import V1FinetuningCreateResponse500Type1Code
from .v1_finetuning_create_response_500_type_2 import V1FinetuningCreateResponse500Type2
from .v1_finetuning_create_response_500_type_2_code import V1FinetuningCreateResponse500Type2Code
from .v1_finetuning_create_response_500_type_3 import V1FinetuningCreateResponse500Type3
from .v1_finetuning_create_response_500_type_3_code import V1FinetuningCreateResponse500Type3Code
from .v1_finetuning_create_response_500_type_4 import V1FinetuningCreateResponse500Type4
from .v1_finetuning_create_response_500_type_4_code import V1FinetuningCreateResponse500Type4Code
from .v1_finetuning_create_response_500_type_5 import V1FinetuningCreateResponse500Type5
from .v1_finetuning_create_response_500_type_5_code import V1FinetuningCreateResponse500Type5Code
from .v1_finetuning_retrieve_response_200 import V1FinetuningRetrieveResponse200
from .v1_finetuning_retrieve_response_400 import V1FinetuningRetrieveResponse400
from .v1_finetuning_retrieve_response_400_code import V1FinetuningRetrieveResponse400Code
from .v1_finetuning_retrieve_response_400_details import V1FinetuningRetrieveResponse400Details
from .v1_finetuning_retrieve_response_400_details_additional_property import (
    V1FinetuningRetrieveResponse400DetailsAdditionalProperty,
)
from .v1_finetuning_retrieve_response_400_details_additional_property_error_messages_item import (
    V1FinetuningRetrieveResponse400DetailsAdditionalPropertyErrorMessagesItem,
)
from .v1_finetuning_retrieve_response_401 import V1FinetuningRetrieveResponse401
from .v1_finetuning_retrieve_response_401_code import V1FinetuningRetrieveResponse401Code
from .v1_finetuning_retrieve_response_403 import V1FinetuningRetrieveResponse403
from .v1_finetuning_retrieve_response_403_code import V1FinetuningRetrieveResponse403Code
from .v1_finetuning_retrieve_response_404_type_0 import V1FinetuningRetrieveResponse404Type0
from .v1_finetuning_retrieve_response_404_type_0_code import V1FinetuningRetrieveResponse404Type0Code
from .v1_finetuning_retrieve_response_404_type_1 import V1FinetuningRetrieveResponse404Type1
from .v1_finetuning_retrieve_response_404_type_1_code import V1FinetuningRetrieveResponse404Type1Code
from .v1_finetuning_retrieve_response_409 import V1FinetuningRetrieveResponse409
from .v1_finetuning_retrieve_response_409_code import V1FinetuningRetrieveResponse409Code
from .v1_finetuning_retrieve_response_422 import V1FinetuningRetrieveResponse422
from .v1_finetuning_retrieve_response_422_code import V1FinetuningRetrieveResponse422Code
from .v1_finetuning_retrieve_response_429 import V1FinetuningRetrieveResponse429
from .v1_finetuning_retrieve_response_429_code import V1FinetuningRetrieveResponse429Code
from .v1_finetuning_retrieve_response_500_type_0 import V1FinetuningRetrieveResponse500Type0
from .v1_finetuning_retrieve_response_500_type_0_code import V1FinetuningRetrieveResponse500Type0Code
from .v1_finetuning_retrieve_response_500_type_1 import V1FinetuningRetrieveResponse500Type1
from .v1_finetuning_retrieve_response_500_type_1_code import V1FinetuningRetrieveResponse500Type1Code
from .v1_finetuning_retrieve_response_500_type_2 import V1FinetuningRetrieveResponse500Type2
from .v1_finetuning_retrieve_response_500_type_2_code import V1FinetuningRetrieveResponse500Type2Code
from .v1_finetuning_retrieve_response_500_type_3 import V1FinetuningRetrieveResponse500Type3
from .v1_finetuning_retrieve_response_500_type_3_code import V1FinetuningRetrieveResponse500Type3Code
from .v1_finetuning_retrieve_response_500_type_4 import V1FinetuningRetrieveResponse500Type4
from .v1_finetuning_retrieve_response_500_type_4_code import V1FinetuningRetrieveResponse500Type4Code
from .v1_finetuning_retrieve_response_500_type_5 import V1FinetuningRetrieveResponse500Type5
from .v1_finetuning_retrieve_response_500_type_5_code import V1FinetuningRetrieveResponse500Type5Code
from .validation_detail import ValidationDetail
from .validation_detail_error_messages_item import ValidationDetailErrorMessagesItem
from .validation_error import ValidationError
from .validation_error_code import ValidationErrorCode
from .validation_error_code_enum import ValidationErrorCodeEnum
from .validation_error_details import ValidationErrorDetails
from .validation_error_details_additional_property import ValidationErrorDetailsAdditionalProperty
from .validation_error_details_additional_property_error_messages_item import (
    ValidationErrorDetailsAdditionalPropertyErrorMessagesItem,
)

__all__ = (
    "ApiProjectsDataPointsCreateDataBody",
    "ApiProjectsDataPointsCreateFilesBody",
    "ApiProjectsDataPointsCreateJsonBody",
    "ApiProjectsDataPointsCreateResponse201",
    "ApiProjectsDataPointsListResponse200Item",
    "ApiProjectsDataPointsPartialUpdateDataBody",
    "ApiProjectsDataPointsPartialUpdateFilesBody",
    "ApiProjectsDataPointsPartialUpdateJsonBody",
    "ApiProjectsDataPointsPartialUpdateResponse200",
    "ApiProjectsDataPointsRetrieveResponse200",
    "ApiProjectsDataPointsUpdateDataBody",
    "ApiProjectsDataPointsUpdateFilesBody",
    "ApiProjectsDataPointsUpdateJsonBody",
    "ApiProjectsDataPointsUpdateResponse200",
    "ApiProjectsTracesCreateDataBody",
    "ApiProjectsTracesCreateDataBodyRawRequestType0",
    "ApiProjectsTracesCreateDataBodyRawResponseType0",
    "ApiProjectsTracesCreateFilesBody",
    "ApiProjectsTracesCreateFilesBodyRawRequestType0",
    "ApiProjectsTracesCreateFilesBodyRawResponseType0",
    "ApiProjectsTracesCreateJsonBody",
    "ApiProjectsTracesCreateJsonBodyRawRequestType0",
    "ApiProjectsTracesCreateJsonBodyRawResponseType0",
    "ApiProjectsTracesCreateResponse201",
    "ApiProjectsTracesCreateResponse201RawRequestType0",
    "ApiProjectsTracesCreateResponse201RawResponseType0",
    "ApiProvidersLeaderboardRetrieveResponse200",
    "ApiProvidersLeaderboardRetrieveResponse200LeaderboardItem",
    "APIResponseValidationError",
    "APIResponseValidationErrorCode",
    "APIResponseValidationErrorCodeEnum",
    "ApiSchemaRetrieveFormat",
    "ApiSchemaRetrieveLang",
    "ApiSchemaRetrieveResponse200",
    "AuthenticationError",
    "AuthenticationErrorCode",
    "AuthenticationErrorCodeEnum",
    "AuthToken",
    "AuthTokenCreateDataBody",
    "AuthTokenCreateFilesBody",
    "AuthTokenCreateJsonBody",
    "AuthTokenCreateResponse200",
    "CatchAllError",
    "CatchAllErrorCode",
    "CatchAllErrorCodeEnum",
    "ChatCompletionInput",
    "ChatCompletionInputLogitBiasType0",
    "ChatCompletionInputMessagesItem",
    "ChatCompletionInputMessagesItemRole",
    "ChatCompletionInputResponseFormatType0",
    "ChatCompletionInputToolsItem",
    "ChatCompletionResponse",
    "ChatCompletionResponseChoicesItem",
    "ChatCompletionResponseUsage",
    "ConflictError",
    "ConflictErrorCode",
    "ConflictErrorCodeEnum",
    "DataPoint",
    "Embedding",
    "EmbeddingsInput",
    "EmbeddingsInputEncodingFormat",
    "EmbeddingsResponse",
    "EmbeddingsResponseDataItem",
    "EmbeddingsResponseUsage",
    "EncodingFormatEnum",
    "FineTuningInput",
    "FineTuningInputTrainingDataItem",
    "FineTuningInputValidatonDataItem",
    "FineTuningResponse",
    "FineTuningSample",
    "InputDataPoint",
    "InternalServerErrorType0",
    "InternalServerErrorType0Code",
    "InternalServerErrorType1",
    "InternalServerErrorType1Code",
    "InternalServerErrorType2",
    "InternalServerErrorType2Code",
    "InternalServerErrorType3",
    "InternalServerErrorType3Code",
    "InternalServerErrorType4",
    "InternalServerErrorType4Code",
    "InternalServerErrorType5",
    "InternalServerErrorType5Code",
    "LeaderboardItem",
    "LeaderboardResponse",
    "LeaderboardResponseLeaderboardItem",
    "Message",
    "MessageRole",
    "ModelNotFoundError",
    "ModelNotFoundErrorCode",
    "ModelNotFoundErrorCodeEnum",
    "NotFoundErrorType0",
    "NotFoundErrorType0Code",
    "NotFoundErrorType1",
    "NotFoundErrorType1Code",
    "PatchedDataPoint",
    "PermissionDeniedError",
    "PermissionDeniedErrorCode",
    "PermissionDeniedErrorCodeEnum",
    "ProviderAPIConnectionError",
    "ProviderAPIConnectionErrorCode",
    "ProviderAPIConnectionErrorCodeEnum",
    "ProviderAPIStatusError",
    "ProviderAPIStatusErrorCode",
    "ProviderAPIStatusErrorCodeEnum",
    "ProviderAPITimeoutError",
    "ProviderAPITimeoutErrorCode",
    "ProviderAPITimeoutErrorCodeEnum",
    "ProviderInternalServerError",
    "ProviderInternalServerErrorCode",
    "ProviderInternalServerErrorCodeEnum",
    "ProviderNotFoundError",
    "ProviderNotFoundErrorCode",
    "ProviderNotFoundErrorCodeEnum",
    "RateLimitError",
    "RateLimitErrorCode",
    "RateLimitErrorCodeEnum",
    "ResponseChoice",
    "RetrieveFineTuningResponse",
    "RoleEnum",
    "Trace",
    "TraceRawRequestType0",
    "TraceRawResponseType0",
    "UnprocessableEntityError",
    "UnprocessableEntityErrorCode",
    "UnprocessableEntityErrorCodeEnum",
    "Usage",
    "V1ChatCompletionsCreateDataBody",
    "V1ChatCompletionsCreateDataBodyLogitBiasType0",
    "V1ChatCompletionsCreateDataBodyMessagesItem",
    "V1ChatCompletionsCreateDataBodyMessagesItemRole",
    "V1ChatCompletionsCreateDataBodyResponseFormatType0",
    "V1ChatCompletionsCreateDataBodyToolsItem",
    "V1ChatCompletionsCreateFilesBody",
    "V1ChatCompletionsCreateFilesBodyLogitBiasType0",
    "V1ChatCompletionsCreateFilesBodyMessagesItem",
    "V1ChatCompletionsCreateFilesBodyMessagesItemRole",
    "V1ChatCompletionsCreateFilesBodyResponseFormatType0",
    "V1ChatCompletionsCreateFilesBodyToolsItem",
    "V1ChatCompletionsCreateJsonBody",
    "V1ChatCompletionsCreateJsonBodyLogitBiasType0",
    "V1ChatCompletionsCreateJsonBodyMessagesItem",
    "V1ChatCompletionsCreateJsonBodyMessagesItemRole",
    "V1ChatCompletionsCreateJsonBodyResponseFormatType0",
    "V1ChatCompletionsCreateJsonBodyToolsItem",
    "V1ChatCompletionsCreateResponse200",
    "V1ChatCompletionsCreateResponse200ChoicesItem",
    "V1ChatCompletionsCreateResponse200Usage",
    "V1ChatCompletionsCreateResponse400",
    "V1ChatCompletionsCreateResponse400Code",
    "V1ChatCompletionsCreateResponse400Details",
    "V1ChatCompletionsCreateResponse400DetailsAdditionalProperty",
    "V1ChatCompletionsCreateResponse400DetailsAdditionalPropertyErrorMessagesItem",
    "V1ChatCompletionsCreateResponse401",
    "V1ChatCompletionsCreateResponse401Code",
    "V1ChatCompletionsCreateResponse403",
    "V1ChatCompletionsCreateResponse403Code",
    "V1ChatCompletionsCreateResponse404Type0",
    "V1ChatCompletionsCreateResponse404Type0Code",
    "V1ChatCompletionsCreateResponse404Type1",
    "V1ChatCompletionsCreateResponse404Type1Code",
    "V1ChatCompletionsCreateResponse409",
    "V1ChatCompletionsCreateResponse409Code",
    "V1ChatCompletionsCreateResponse422",
    "V1ChatCompletionsCreateResponse422Code",
    "V1ChatCompletionsCreateResponse429",
    "V1ChatCompletionsCreateResponse429Code",
    "V1ChatCompletionsCreateResponse500Type0",
    "V1ChatCompletionsCreateResponse500Type0Code",
    "V1ChatCompletionsCreateResponse500Type1",
    "V1ChatCompletionsCreateResponse500Type1Code",
    "V1ChatCompletionsCreateResponse500Type2",
    "V1ChatCompletionsCreateResponse500Type2Code",
    "V1ChatCompletionsCreateResponse500Type3",
    "V1ChatCompletionsCreateResponse500Type3Code",
    "V1ChatCompletionsCreateResponse500Type4",
    "V1ChatCompletionsCreateResponse500Type4Code",
    "V1ChatCompletionsCreateResponse500Type5",
    "V1ChatCompletionsCreateResponse500Type5Code",
    "V1EmbeddingsCreateDataBody",
    "V1EmbeddingsCreateDataBodyEncodingFormat",
    "V1EmbeddingsCreateFilesBody",
    "V1EmbeddingsCreateFilesBodyEncodingFormat",
    "V1EmbeddingsCreateJsonBody",
    "V1EmbeddingsCreateJsonBodyEncodingFormat",
    "V1EmbeddingsCreateResponse200",
    "V1EmbeddingsCreateResponse200DataItem",
    "V1EmbeddingsCreateResponse200Usage",
    "V1EmbeddingsCreateResponse400",
    "V1EmbeddingsCreateResponse400Code",
    "V1EmbeddingsCreateResponse400Details",
    "V1EmbeddingsCreateResponse400DetailsAdditionalProperty",
    "V1EmbeddingsCreateResponse400DetailsAdditionalPropertyErrorMessagesItem",
    "V1EmbeddingsCreateResponse401",
    "V1EmbeddingsCreateResponse401Code",
    "V1EmbeddingsCreateResponse403",
    "V1EmbeddingsCreateResponse403Code",
    "V1EmbeddingsCreateResponse404Type0",
    "V1EmbeddingsCreateResponse404Type0Code",
    "V1EmbeddingsCreateResponse404Type1",
    "V1EmbeddingsCreateResponse404Type1Code",
    "V1EmbeddingsCreateResponse409",
    "V1EmbeddingsCreateResponse409Code",
    "V1EmbeddingsCreateResponse422",
    "V1EmbeddingsCreateResponse422Code",
    "V1EmbeddingsCreateResponse429",
    "V1EmbeddingsCreateResponse429Code",
    "V1EmbeddingsCreateResponse500Type0",
    "V1EmbeddingsCreateResponse500Type0Code",
    "V1EmbeddingsCreateResponse500Type1",
    "V1EmbeddingsCreateResponse500Type1Code",
    "V1EmbeddingsCreateResponse500Type2",
    "V1EmbeddingsCreateResponse500Type2Code",
    "V1EmbeddingsCreateResponse500Type3",
    "V1EmbeddingsCreateResponse500Type3Code",
    "V1EmbeddingsCreateResponse500Type4",
    "V1EmbeddingsCreateResponse500Type4Code",
    "V1EmbeddingsCreateResponse500Type5",
    "V1EmbeddingsCreateResponse500Type5Code",
    "V1FinetuningCreateDataBody",
    "V1FinetuningCreateDataBodyTrainingDataItem",
    "V1FinetuningCreateDataBodyValidatonDataItem",
    "V1FinetuningCreateFilesBody",
    "V1FinetuningCreateFilesBodyTrainingDataItem",
    "V1FinetuningCreateFilesBodyValidatonDataItem",
    "V1FinetuningCreateJsonBody",
    "V1FinetuningCreateJsonBodyTrainingDataItem",
    "V1FinetuningCreateJsonBodyValidatonDataItem",
    "V1FinetuningCreateResponse200",
    "V1FinetuningCreateResponse400",
    "V1FinetuningCreateResponse400Code",
    "V1FinetuningCreateResponse400Details",
    "V1FinetuningCreateResponse400DetailsAdditionalProperty",
    "V1FinetuningCreateResponse400DetailsAdditionalPropertyErrorMessagesItem",
    "V1FinetuningCreateResponse401",
    "V1FinetuningCreateResponse401Code",
    "V1FinetuningCreateResponse403",
    "V1FinetuningCreateResponse403Code",
    "V1FinetuningCreateResponse404Type0",
    "V1FinetuningCreateResponse404Type0Code",
    "V1FinetuningCreateResponse404Type1",
    "V1FinetuningCreateResponse404Type1Code",
    "V1FinetuningCreateResponse409",
    "V1FinetuningCreateResponse409Code",
    "V1FinetuningCreateResponse422",
    "V1FinetuningCreateResponse422Code",
    "V1FinetuningCreateResponse429",
    "V1FinetuningCreateResponse429Code",
    "V1FinetuningCreateResponse500Type0",
    "V1FinetuningCreateResponse500Type0Code",
    "V1FinetuningCreateResponse500Type1",
    "V1FinetuningCreateResponse500Type1Code",
    "V1FinetuningCreateResponse500Type2",
    "V1FinetuningCreateResponse500Type2Code",
    "V1FinetuningCreateResponse500Type3",
    "V1FinetuningCreateResponse500Type3Code",
    "V1FinetuningCreateResponse500Type4",
    "V1FinetuningCreateResponse500Type4Code",
    "V1FinetuningCreateResponse500Type5",
    "V1FinetuningCreateResponse500Type5Code",
    "V1FinetuningRetrieveResponse200",
    "V1FinetuningRetrieveResponse400",
    "V1FinetuningRetrieveResponse400Code",
    "V1FinetuningRetrieveResponse400Details",
    "V1FinetuningRetrieveResponse400DetailsAdditionalProperty",
    "V1FinetuningRetrieveResponse400DetailsAdditionalPropertyErrorMessagesItem",
    "V1FinetuningRetrieveResponse401",
    "V1FinetuningRetrieveResponse401Code",
    "V1FinetuningRetrieveResponse403",
    "V1FinetuningRetrieveResponse403Code",
    "V1FinetuningRetrieveResponse404Type0",
    "V1FinetuningRetrieveResponse404Type0Code",
    "V1FinetuningRetrieveResponse404Type1",
    "V1FinetuningRetrieveResponse404Type1Code",
    "V1FinetuningRetrieveResponse409",
    "V1FinetuningRetrieveResponse409Code",
    "V1FinetuningRetrieveResponse422",
    "V1FinetuningRetrieveResponse422Code",
    "V1FinetuningRetrieveResponse429",
    "V1FinetuningRetrieveResponse429Code",
    "V1FinetuningRetrieveResponse500Type0",
    "V1FinetuningRetrieveResponse500Type0Code",
    "V1FinetuningRetrieveResponse500Type1",
    "V1FinetuningRetrieveResponse500Type1Code",
    "V1FinetuningRetrieveResponse500Type2",
    "V1FinetuningRetrieveResponse500Type2Code",
    "V1FinetuningRetrieveResponse500Type3",
    "V1FinetuningRetrieveResponse500Type3Code",
    "V1FinetuningRetrieveResponse500Type4",
    "V1FinetuningRetrieveResponse500Type4Code",
    "V1FinetuningRetrieveResponse500Type5",
    "V1FinetuningRetrieveResponse500Type5Code",
    "ValidationDetail",
    "ValidationDetailErrorMessagesItem",
    "ValidationError",
    "ValidationErrorCode",
    "ValidationErrorCodeEnum",
    "ValidationErrorDetails",
    "ValidationErrorDetailsAdditionalProperty",
    "ValidationErrorDetailsAdditionalPropertyErrorMessagesItem",
    "ApiProjectsDataPointsCreateJsonBodyDict",
    "ApiProjectsDataPointsCreateDataBodyDict",
    "ApiProjectsDataPointsCreateFilesBodyDict",
    "ApiProjectsDataPointsUpdateJsonBodyDict",
    "ApiProjectsDataPointsUpdateDataBodyDict",
    "ApiProjectsDataPointsUpdateFilesBodyDict",
    "ApiProjectsDataPointsPartialUpdateJsonBodyDict",
    "ApiProjectsDataPointsPartialUpdateDataBodyDict",
    "ApiProjectsDataPointsPartialUpdateFilesBodyDict",
    "ApiProjectsTracesCreateJsonBodyDict",
    "ApiProjectsTracesCreateDataBodyDict",
    "ApiProjectsTracesCreateFilesBodyDict",
    "AuthTokenCreateDataBodyDict",
    "AuthTokenCreateFilesBodyDict",
    "AuthTokenCreateJsonBodyDict",
    "V1ChatCompletionsCreateJsonBodyDict",
    "V1ChatCompletionsCreateDataBodyDict",
    "V1ChatCompletionsCreateFilesBodyDict",
    "V1EmbeddingsCreateJsonBodyDict",
    "V1EmbeddingsCreateDataBodyDict",
    "V1EmbeddingsCreateFilesBodyDict",
    "V1FinetuningCreateJsonBodyDict",
    "V1FinetuningCreateDataBodyDict",
    "V1FinetuningCreateFilesBodyDict",
)



from enum import Enum


class V1ChatCompletionsCreateResponse500Type2Code(str, Enum):
    PROVIDERAPISTATUSERROR = "ProviderAPIStatusError"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class V1ChatCompletionsCreateResponse404Type0Code(str, Enum):
    PROVIDERNOTFOUNDERROR = "ProviderNotFoundError"

    def __str__(self) -> str:
        return str(self.value)



from http import HTTPStatus
from typing import Dict, Optional, Union

import httpx
from typing_extensions import Any, Unpack

from ... import errors
from ...models.v1_embeddings_create_json_body import V1EmbeddingsCreateJsonBody
from ...models.v1_embeddings_create_response_200 import V1EmbeddingsCreateResponse200
from ...models.v1_embeddings_create_response_400 import V1EmbeddingsCreateResponse400
from ...models.v1_embeddings_create_response_401 import V1EmbeddingsCreateResponse401
from ...models.v1_embeddings_create_response_403 import V1EmbeddingsCreateResponse403
from ...models.v1_embeddings_create_response_404_type_0 import V1EmbeddingsCreateResponse404Type0
from ...models.v1_embeddings_create_response_404_type_1 import V1EmbeddingsCreateResponse404Type1
from ...models.v1_embeddings_create_response_409 import V1EmbeddingsCreateResponse409
from ...models.v1_embeddings_create_response_422 import V1EmbeddingsCreateResponse422
from ...models.v1_embeddings_create_response_429 import V1EmbeddingsCreateResponse429
from ...models.v1_embeddings_create_response_500_type_0 import V1EmbeddingsCreateResponse500Type0
from ...models.v1_embeddings_create_response_500_type_1 import V1EmbeddingsCreateResponse500Type1
from ...models.v1_embeddings_create_response_500_type_2 import V1EmbeddingsCreateResponse500Type2
from ...models.v1_embeddings_create_response_500_type_3 import V1EmbeddingsCreateResponse500Type3
from ...models.v1_embeddings_create_response_500_type_4 import V1EmbeddingsCreateResponse500Type4
from ...models.v1_embeddings_create_response_500_type_5 import V1EmbeddingsCreateResponse500Type5

# from ...client import AuthenticatedClient, Client
from ...types import Response


def _get_kwargs(
    **body: Unpack[V1EmbeddingsCreateJsonBody],
) -> Dict[str, Any]:
    headers: Dict[str, Any] = {}

    _kwargs: Dict[str, Any] = {
        "method": "post",
        "url": "/v1/embeddings",
    }

    _json_body = body

    _kwargs["json"] = _json_body
    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client, response: httpx.Response
) -> Optional[
    Union[
        Union["V1EmbeddingsCreateResponse404Type0", "V1EmbeddingsCreateResponse404Type1"],
        Union[
            "V1EmbeddingsCreateResponse500Type0",
            "V1EmbeddingsCreateResponse500Type1",
            "V1EmbeddingsCreateResponse500Type2",
            "V1EmbeddingsCreateResponse500Type3",
            "V1EmbeddingsCreateResponse500Type4",
            "V1EmbeddingsCreateResponse500Type5",
        ],
        V1EmbeddingsCreateResponse200,
        V1EmbeddingsCreateResponse400,
        V1EmbeddingsCreateResponse401,
        V1EmbeddingsCreateResponse403,
        V1EmbeddingsCreateResponse409,
        V1EmbeddingsCreateResponse422,
        V1EmbeddingsCreateResponse429,
    ]
]:
    if response.status_code == HTTPStatus.OK:
        response_200 = V1EmbeddingsCreateResponse200.from_dict(response.json())

        return response_200
    if response.status_code == HTTPStatus.BAD_REQUEST:
        response_400 = V1EmbeddingsCreateResponse400.from_dict(response.json())

        return response_400
    if response.status_code == HTTPStatus.UNAUTHORIZED:
        response_401 = V1EmbeddingsCreateResponse401.from_dict(response.json())

        return response_401
    if response.status_code == HTTPStatus.FORBIDDEN:
        response_403 = V1EmbeddingsCreateResponse403.from_dict(response.json())

        return response_403
    if response.status_code == HTTPStatus.NOT_FOUND:

        def _parse_response_404(
            data: object,
        ) -> Union["V1EmbeddingsCreateResponse404Type0", "V1EmbeddingsCreateResponse404Type1"]:
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                response_404_type_0 = V1EmbeddingsCreateResponse404Type0.from_dict(data)

                return response_404_type_0
            except:  # noqa: E722
                pass
            if not isinstance(data, dict):
                raise TypeError()
            response_404_type_1 = V1EmbeddingsCreateResponse404Type1.from_dict(data)

            return response_404_type_1

        response_404 = _parse_response_404(response.json())

        return response_404
    if response.status_code == HTTPStatus.CONFLICT:
        response_409 = V1EmbeddingsCreateResponse409.from_dict(response.json())

        return response_409
    if response.status_code == HTTPStatus.UNPROCESSABLE_ENTITY:
        response_422 = V1EmbeddingsCreateResponse422.from_dict(response.json())

        return response_422
    if response.status_code == HTTPStatus.TOO_MANY_REQUESTS:
        response_429 = V1EmbeddingsCreateResponse429.from_dict(response.json())

        return response_429
    if response.status_code == HTTPStatus.INTERNAL_SERVER_ERROR:

        def _parse_response_500(
            data: object,
        ) -> Union[
            "V1EmbeddingsCreateResponse500Type0",
            "V1EmbeddingsCreateResponse500Type1",
            "V1EmbeddingsCreateResponse500Type2",
            "V1EmbeddingsCreateResponse500Type3",
            "V1EmbeddingsCreateResponse500Type4",
            "V1EmbeddingsCreateResponse500Type5",
        ]:
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                response_500_type_0 = V1EmbeddingsCreateResponse500Type0.from_dict(data)

                return response_500_type_0
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                response_500_type_1 = V1EmbeddingsCreateResponse500Type1.from_dict(data)

                return response_500_type_1
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                response_500_type_2 = V1EmbeddingsCreateResponse500Type2.from_dict(data)

                return response_500_type_2
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                response_500_type_3 = V1EmbeddingsCreateResponse500Type3.from_dict(data)

                return response_500_type_3
            except:  # noqa: E722
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                response_500_type_4 = V1EmbeddingsCreateResponse500Type4.from_dict(data)

                return response_500_type_4
            except:  # noqa: E722
                pass
            if not isinstance(data, dict):
                raise TypeError()
            response_500_type_5 = V1EmbeddingsCreateResponse500Type5.from_dict(data)

            return response_500_type_5

        response_500 = _parse_response_500(response.json())

        return response_500
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client, response: httpx.Response
) -> Response[
    Union[
        Union["V1EmbeddingsCreateResponse404Type0", "V1EmbeddingsCreateResponse404Type1"],
        Union[
            "V1EmbeddingsCreateResponse500Type0",
            "V1EmbeddingsCreateResponse500Type1",
            "V1EmbeddingsCreateResponse500Type2",
            "V1EmbeddingsCreateResponse500Type3",
            "V1EmbeddingsCreateResponse500Type4",
            "V1EmbeddingsCreateResponse500Type5",
        ],
        V1EmbeddingsCreateResponse200,
        V1EmbeddingsCreateResponse400,
        V1EmbeddingsCreateResponse401,
        V1EmbeddingsCreateResponse403,
        V1EmbeddingsCreateResponse409,
        V1EmbeddingsCreateResponse422,
        V1EmbeddingsCreateResponse429,
    ]
]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def v1_embeddings_create_wrapper(client):
    def v1_embeddings_create_wrapped(
        **body: Unpack[V1EmbeddingsCreateJsonBody],
    ) -> Union[
        Union["V1EmbeddingsCreateResponse404Type0", "V1EmbeddingsCreateResponse404Type1"],
        Union[
            "V1EmbeddingsCreateResponse500Type0",
            "V1EmbeddingsCreateResponse500Type1",
            "V1EmbeddingsCreateResponse500Type2",
            "V1EmbeddingsCreateResponse500Type3",
            "V1EmbeddingsCreateResponse500Type4",
            "V1EmbeddingsCreateResponse500Type5",
        ],
        V1EmbeddingsCreateResponse200,
        V1EmbeddingsCreateResponse400,
        V1EmbeddingsCreateResponse401,
        V1EmbeddingsCreateResponse403,
        V1EmbeddingsCreateResponse409,
        V1EmbeddingsCreateResponse422,
        V1EmbeddingsCreateResponse429,
    ]:
        """Creates embeddings for the given input.

        Args:
            authorization (str):
            body (V1EmbeddingsCreateJsonBody):
            body (V1EmbeddingsCreateDataBody):
            body (V1EmbeddingsCreateFilesBody):

        Raises:
            errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
            httpx.TimeoutException: If the request takes longer than Client.timeout.

        Returns:
            Response[Union[Union['V1EmbeddingsCreateResponse404Type0', 'V1EmbeddingsCreateResponse404Type1'], Union['V1EmbeddingsCreateResponse500Type0', 'V1EmbeddingsCreateResponse500Type1', 'V1EmbeddingsCreateResponse500Type2', 'V1EmbeddingsCreateResponse500Type3', 'V1EmbeddingsCreateResponse500Type4', 'V1EmbeddingsCreateResponse500Type5'], V1EmbeddingsCreateResponse200, V1EmbeddingsCreateResponse400, V1EmbeddingsCreateResponse401, V1EmbeddingsCreateResponse403, V1EmbeddingsCreateResponse409, V1EmbeddingsCreateResponse422, V1EmbeddingsCreateResponse429]]
        """

        kwargs = _get_kwargs(
            **body,
        )

        httpx_client = client.get_httpx_client()

        response = httpx_client.request(
            **kwargs,
        )

        return _build_response(client=client, response=response).parsed

    return v1_embeddings_create_wrapped



from typing import Dict, List, Type, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from typing_extensions import Any, NotRequired, TypedDict, TypeVar

from ..models.v1_embeddings_create_json_body_encoding_format import V1EmbeddingsCreateJsonBodyEncodingFormat
from ..types import UNSET, Unset

T = TypeVar("T", bound="V1EmbeddingsCreateJsonBody")


class V1EmbeddingsCreateJsonBodyDict(TypedDict):
    project_id: int
    input_: List[Union[List[List[int]], List[int], List[str], str]]
    model: NotRequired[Union[Unset, str]]
    encoding_format: NotRequired[Union[Unset, V1EmbeddingsCreateJsonBodyEncodingFormat]]
    pass


@_attrs_define
class V1EmbeddingsCreateJsonBody:
    """
    Attributes:
        project_id (int): The ID of the project to use.
        input_ (List[Union[List[List[int]], List[int], List[str], str]]): Embedding Input
        model (Union[Unset, str]):
        encoding_format (Union[Unset, V1EmbeddingsCreateJsonBodyEncodingFormat]):
    """

    project_id: int
    input_: List[Union[List[List[int]], List[int], List[str], str]]
    model: Union[Unset, str] = UNSET
    encoding_format: Union[Unset, "V1EmbeddingsCreateJsonBodyEncodingFormat"] = UNSET

    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        project_id = self.project_id

        input_ = []
        for input_item_data in self.input_:
            input_item: Union[List[List[int]], List[int], List[str], str]
            if isinstance(input_item_data, list):
                input_item = input_item_data

            elif isinstance(input_item_data, list):
                input_item = input_item_data

            elif isinstance(input_item_data, list):
                input_item = []
                for input_item_type_3_item_data in input_item_data:
                    input_item_type_3_item = input_item_type_3_item_data

                    input_item.append(input_item_type_3_item)

            else:
                input_item = input_item_data
            input_.append(input_item)

        model = self.model

        encoding_format: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.encoding_format, Unset):
            encoding_format = self.encoding_format.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "project_id": project_id,
                "input": input_,
            }
        )
        if model is not UNSET:
            field_dict["model"] = model
        if encoding_format is not UNSET:
            field_dict["encoding_format"] = encoding_format

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.v1_embeddings_create_json_body_encoding_format import V1EmbeddingsCreateJsonBodyEncodingFormat

        d = src_dict.copy()
        project_id = d.pop("project_id")

        input_ = []
        _input_ = d.pop("input")
        for input_item_data in _input_:

            def _parse_input_item(data: object) -> Union[List[List[int]], List[int], List[str], str]:
                try:
                    if not isinstance(data, list):
                        raise TypeError()
                    input_item_type_1 = cast(List[str], data)

                    return input_item_type_1
                except:  # noqa: E722
                    pass
                try:
                    if not isinstance(data, list):
                        raise TypeError()
                    input_item_type_2 = cast(List[int], data)

                    return input_item_type_2
                except:  # noqa: E722
                    pass
                try:
                    if not isinstance(data, list):
                        raise TypeError()
                    input_item_type_3 = []
                    _input_item_type_3 = data
                    for input_item_type_3_item_data in _input_item_type_3:
                        input_item_type_3_item = cast(List[int], input_item_type_3_item_data)

                        input_item_type_3.append(input_item_type_3_item)

                    return input_item_type_3
                except:  # noqa: E722
                    pass
                return cast(Union[List[List[int]], List[int], List[str], str], data)

            input_item = _parse_input_item(input_item_data)

            input_.append(input_item)

        model = d.pop("model", UNSET)

        _encoding_format = d.pop("encoding_format", UNSET)
        encoding_format: Union[Unset, V1EmbeddingsCreateJsonBodyEncodingFormat]
        if isinstance(_encoding_format, Unset):
            encoding_format = UNSET
        else:
            encoding_format = V1EmbeddingsCreateJsonBodyEncodingFormat.from_dict(_encoding_format)

        v1_embeddings_create_json_body = cls(
            project_id=project_id,
            input_=input_,
            model=model,
            encoding_format=encoding_format,
        )

        v1_embeddings_create_json_body.additional_properties = d
        return v1_embeddings_create_json_body

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from .client import AuthenticatedClient

from .api import (
    PlaygroundsModule,
    DatapointsModule,
    TracesModule,
    ProvidersModule,
    ApiModule,
    EmbeddingsModule,
    FinetuningModule,
    AuthModuleWrapper,
    ChatModuleWrapper,
)

class Prem:
    playgrounds: PlaygroundsModule
    datapoints: DatapointsModule
    traces: TracesModule
    providers: ProvidersModule
    api: ApiModule
    embeddings: EmbeddingsModule
    finetuning: FinetuningModule
    auth: AuthModuleWrapper
    chat: ChatModuleWrapper

    def __init__(self, api_key: str, base_url='https://app.premai.io'):
        client = AuthenticatedClient(token=api_key, base_url=base_url)
        # Init modules
        self.playgrounds = PlaygroundsModule(client)
        self.datapoints = DatapointsModule(client)
        self.traces = TracesModule(client)
        self.providers = ProvidersModule(client)
        self.api = ApiModule(client)
        self.embeddings = EmbeddingsModule(client)
        self.finetuning = FinetuningModule(client)
        self.auth = AuthModuleWrapper(client)
        self.chat = ChatModuleWrapper(client)

__all__ = [
    "Prem"
]


from enum import Enum


class V1FinetuningRetrieveResponse500Type3Code(str, Enum):
    PROVIDERAPITIMEOUTERROR = "ProviderAPITimeoutError"

    def __str__(self) -> str:
        return str(self.value)



from http import HTTPStatus
from typing import Dict, Optional, Union

import httpx
from typing_extensions import Any

from ... import errors
from ...models.api_schema_retrieve_format import ApiSchemaRetrieveFormat
from ...models.api_schema_retrieve_lang import ApiSchemaRetrieveLang
from ...models.api_schema_retrieve_response_200 import ApiSchemaRetrieveResponse200

# from ...client import AuthenticatedClient, Client
from ...types import UNSET, Response, Unset


def _get_kwargs(
    format_: Union[Unset, ApiSchemaRetrieveFormat] = UNSET,
    lang: Union[Unset, ApiSchemaRetrieveLang] = UNSET,
) -> Dict[str, Any]:
    params: Dict[str, Any] = {}

    json_format_: Union[Unset, str] = UNSET
    if not isinstance(format_, Unset):
        json_format_ = format_.value

    params["format"] = json_format_

    json_lang: Union[Unset, str] = UNSET
    if not isinstance(lang, Unset):
        json_lang = lang.value

    params["lang"] = json_lang

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: Dict[str, Any] = {
        "method": "get",
        "url": "/api/schema/",
        "params": params,
    }

    return _kwargs


def _parse_response(*, client, response: httpx.Response) -> Optional[ApiSchemaRetrieveResponse200]:
    if response.status_code == HTTPStatus.OK:
        response_200 = ApiSchemaRetrieveResponse200.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(*, client, response: httpx.Response) -> Response[ApiSchemaRetrieveResponse200]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def api_schema_retrieve_wrapper(client):
    def api_schema_retrieve_wrapped(
        format_: Union[Unset, ApiSchemaRetrieveFormat] = UNSET,
        lang: Union[Unset, ApiSchemaRetrieveLang] = UNSET,
    ) -> ApiSchemaRetrieveResponse200:
        """OpenApi3 schema for this API. Format can be selected via content negotiation.

        - YAML: application/vnd.oai.openapi
        - JSON: application/vnd.oai.openapi+json

        Args:
            format_ (Union[Unset, ApiSchemaRetrieveFormat]):
            lang (Union[Unset, ApiSchemaRetrieveLang]):

        Raises:
            errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
            httpx.TimeoutException: If the request takes longer than Client.timeout.

        Returns:
            Response[ApiSchemaRetrieveResponse200]
        """

        kwargs = _get_kwargs(
            format_=format_,
            lang=lang,
        )

        httpx_client = client.get_httpx_client()

        response = httpx_client.request(
            **kwargs,
        )

        return _build_response(client=client, response=response).parsed

    return api_schema_retrieve_wrapped



import datetime
from typing import Dict, List, Type, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse
from typing_extensions import Any, NotRequired, TypedDict, TypeVar

from ..models.api_projects_traces_create_json_body_raw_request_type_0 import (
    ApiProjectsTracesCreateJsonBodyRawRequestType0,
)
from ..models.api_projects_traces_create_json_body_raw_response_type_0 import (
    ApiProjectsTracesCreateJsonBodyRawResponseType0,
)
from ..types import UNSET, Unset

T = TypeVar("T", bound="ApiProjectsTracesCreateJsonBody")


class ApiProjectsTracesCreateJsonBodyDict(TypedDict):
    id: str
    model_name: str
    created_at: datetime.datetime
    updated_at: datetime.datetime
    start_time: datetime.datetime
    end_time: datetime.datetime
    input_prompt_tokens_number: int
    output_text_tokens_number: int
    is_deleted: NotRequired[Union[Unset, bool]]
    input_prompt: NotRequired[Union[Unset, str]]
    input_file_prompt: NotRequired[Union[None, Unset, str]]
    endpoint_type: NotRequired[Union[None, Unset, str]]
    privacy_score: NotRequired[Union[None, Unset, str]]
    output_text: NotRequired[Union[Unset, str]]
    http_status_code: NotRequired[Union[None, Unset, int]]
    raw_request: NotRequired[Union["ApiProjectsTracesCreateJsonBodyRawRequestType0", None, Unset]]
    raw_response: NotRequired[Union["ApiProjectsTracesCreateJsonBodyRawResponseType0", None, Unset]]
    tag: NotRequired[Union[None, Unset, str]]
    error: NotRequired[Union[None, Unset, str]]
    text_to_text_model_parameters: NotRequired[Union[None, Unset, int]]
    api_key: NotRequired[Union[None, Unset, int]]
    pass


@_attrs_define
class ApiProjectsTracesCreateJsonBody:
    """
    Attributes:
        id (str):
        model_name (str):
        created_at (datetime.datetime):
        updated_at (datetime.datetime):
        start_time (datetime.datetime):
        end_time (datetime.datetime):
        input_prompt_tokens_number (int):
        output_text_tokens_number (int):
        is_deleted (Union[Unset, bool]):
        input_prompt (Union[Unset, str]):
        input_file_prompt (Union[None, Unset, str]):
        endpoint_type (Union[None, Unset, str]):
        privacy_score (Union[None, Unset, str]):
        output_text (Union[Unset, str]):
        http_status_code (Union[None, Unset, int]):
        raw_request (Union['ApiProjectsTracesCreateJsonBodyRawRequestType0', None, Unset]):
        raw_response (Union['ApiProjectsTracesCreateJsonBodyRawResponseType0', None, Unset]):
        tag (Union[None, Unset, str]):
        error (Union[None, Unset, str]):
        text_to_text_model_parameters (Union[None, Unset, int]):
        api_key (Union[None, Unset, int]):
    """

    id: str
    model_name: str
    created_at: datetime.datetime
    updated_at: datetime.datetime
    start_time: datetime.datetime
    end_time: datetime.datetime
    input_prompt_tokens_number: int
    output_text_tokens_number: int
    is_deleted: Union[Unset, bool] = UNSET
    input_prompt: Union[Unset, str] = UNSET
    input_file_prompt: Union[None, Unset, str] = UNSET
    endpoint_type: Union[None, Unset, str] = UNSET
    privacy_score: Union[None, Unset, str] = UNSET
    output_text: Union[Unset, str] = UNSET
    http_status_code: Union[None, Unset, int] = UNSET
    raw_request: Union["ApiProjectsTracesCreateJsonBodyRawRequestType0", None, Unset] = UNSET
    raw_response: Union["ApiProjectsTracesCreateJsonBodyRawResponseType0", None, Unset] = UNSET
    tag: Union[None, Unset, str] = UNSET
    error: Union[None, Unset, str] = UNSET
    text_to_text_model_parameters: Union[None, Unset, int] = UNSET
    api_key: Union[None, Unset, int] = UNSET

    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        from ..models.api_projects_traces_create_json_body_raw_request_type_0 import (
            ApiProjectsTracesCreateJsonBodyRawRequestType0,
        )
        from ..models.api_projects_traces_create_json_body_raw_response_type_0 import (
            ApiProjectsTracesCreateJsonBodyRawResponseType0,
        )

        id = self.id

        model_name = self.model_name

        created_at = self.created_at.isoformat()

        updated_at = self.updated_at.isoformat()

        start_time = self.start_time.isoformat()

        end_time = self.end_time.isoformat()

        input_prompt_tokens_number = self.input_prompt_tokens_number

        output_text_tokens_number = self.output_text_tokens_number

        is_deleted = self.is_deleted

        input_prompt = self.input_prompt

        input_file_prompt: Union[None, Unset, str]
        if isinstance(self.input_file_prompt, Unset):
            input_file_prompt = UNSET
        else:
            input_file_prompt = self.input_file_prompt

        endpoint_type: Union[None, Unset, str]
        if isinstance(self.endpoint_type, Unset):
            endpoint_type = UNSET
        else:
            endpoint_type = self.endpoint_type

        privacy_score: Union[None, Unset, str]
        if isinstance(self.privacy_score, Unset):
            privacy_score = UNSET
        else:
            privacy_score = self.privacy_score

        output_text = self.output_text

        http_status_code: Union[None, Unset, int]
        if isinstance(self.http_status_code, Unset):
            http_status_code = UNSET
        else:
            http_status_code = self.http_status_code

        raw_request: Union[Dict[str, Any], None, Unset]
        if isinstance(self.raw_request, Unset):
            raw_request = UNSET
        elif isinstance(self.raw_request, ApiProjectsTracesCreateJsonBodyRawRequestType0):
            raw_request = self.raw_request.to_dict()
        else:
            raw_request = self.raw_request

        raw_response: Union[Dict[str, Any], None, Unset]
        if isinstance(self.raw_response, Unset):
            raw_response = UNSET
        elif isinstance(self.raw_response, ApiProjectsTracesCreateJsonBodyRawResponseType0):
            raw_response = self.raw_response.to_dict()
        else:
            raw_response = self.raw_response

        tag: Union[None, Unset, str]
        if isinstance(self.tag, Unset):
            tag = UNSET
        else:
            tag = self.tag

        error: Union[None, Unset, str]
        if isinstance(self.error, Unset):
            error = UNSET
        else:
            error = self.error

        text_to_text_model_parameters: Union[None, Unset, int]
        if isinstance(self.text_to_text_model_parameters, Unset):
            text_to_text_model_parameters = UNSET
        else:
            text_to_text_model_parameters = self.text_to_text_model_parameters

        api_key: Union[None, Unset, int]
        if isinstance(self.api_key, Unset):
            api_key = UNSET
        else:
            api_key = self.api_key

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "id": id,
                "model_name": model_name,
                "created_at": created_at,
                "updated_at": updated_at,
                "start_time": start_time,
                "end_time": end_time,
                "input_prompt_tokens_number": input_prompt_tokens_number,
                "output_text_tokens_number": output_text_tokens_number,
            }
        )
        if is_deleted is not UNSET:
            field_dict["is_deleted"] = is_deleted
        if input_prompt is not UNSET:
            field_dict["input_prompt"] = input_prompt
        if input_file_prompt is not UNSET:
            field_dict["input_file_prompt"] = input_file_prompt
        if endpoint_type is not UNSET:
            field_dict["endpoint_type"] = endpoint_type
        if privacy_score is not UNSET:
            field_dict["privacy_score"] = privacy_score
        if output_text is not UNSET:
            field_dict["output_text"] = output_text
        if http_status_code is not UNSET:
            field_dict["http_status_code"] = http_status_code
        if raw_request is not UNSET:
            field_dict["raw_request"] = raw_request
        if raw_response is not UNSET:
            field_dict["raw_response"] = raw_response
        if tag is not UNSET:
            field_dict["tag"] = tag
        if error is not UNSET:
            field_dict["error"] = error
        if text_to_text_model_parameters is not UNSET:
            field_dict["text_to_text_model_parameters"] = text_to_text_model_parameters
        if api_key is not UNSET:
            field_dict["api_key"] = api_key

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.api_projects_traces_create_json_body_raw_request_type_0 import (
            ApiProjectsTracesCreateJsonBodyRawRequestType0,
        )
        from ..models.api_projects_traces_create_json_body_raw_response_type_0 import (
            ApiProjectsTracesCreateJsonBodyRawResponseType0,
        )

        d = src_dict.copy()
        id = d.pop("id")

        model_name = d.pop("model_name")

        created_at = isoparse(d.pop("created_at"))

        updated_at = isoparse(d.pop("updated_at"))

        start_time = isoparse(d.pop("start_time"))

        end_time = isoparse(d.pop("end_time"))

        input_prompt_tokens_number = d.pop("input_prompt_tokens_number")

        output_text_tokens_number = d.pop("output_text_tokens_number")

        is_deleted = d.pop("is_deleted", UNSET)

        input_prompt = d.pop("input_prompt", UNSET)

        def _parse_input_file_prompt(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        input_file_prompt = _parse_input_file_prompt(d.pop("input_file_prompt", UNSET))

        def _parse_endpoint_type(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        endpoint_type = _parse_endpoint_type(d.pop("endpoint_type", UNSET))

        def _parse_privacy_score(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        privacy_score = _parse_privacy_score(d.pop("privacy_score", UNSET))

        output_text = d.pop("output_text", UNSET)

        def _parse_http_status_code(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        http_status_code = _parse_http_status_code(d.pop("http_status_code", UNSET))

        def _parse_raw_request(data: object) -> Union["ApiProjectsTracesCreateJsonBodyRawRequestType0", None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                raw_request_type_0 = ApiProjectsTracesCreateJsonBodyRawRequestType0.from_dict(data)

                return raw_request_type_0
            except:  # noqa: E722
                pass
            return cast(Union["ApiProjectsTracesCreateJsonBodyRawRequestType0", None, Unset], data)

        raw_request = _parse_raw_request(d.pop("raw_request", UNSET))

        def _parse_raw_response(data: object) -> Union["ApiProjectsTracesCreateJsonBodyRawResponseType0", None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                raw_response_type_0 = ApiProjectsTracesCreateJsonBodyRawResponseType0.from_dict(data)

                return raw_response_type_0
            except:  # noqa: E722
                pass
            return cast(Union["ApiProjectsTracesCreateJsonBodyRawResponseType0", None, Unset], data)

        raw_response = _parse_raw_response(d.pop("raw_response", UNSET))

        def _parse_tag(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        tag = _parse_tag(d.pop("tag", UNSET))

        def _parse_error(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        error = _parse_error(d.pop("error", UNSET))

        def _parse_text_to_text_model_parameters(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        text_to_text_model_parameters = _parse_text_to_text_model_parameters(
            d.pop("text_to_text_model_parameters", UNSET)
        )

        def _parse_api_key(data: object) -> Union[None, Unset, int]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, int], data)

        api_key = _parse_api_key(d.pop("api_key", UNSET))

        api_projects_traces_create_json_body = cls(
            id=id,
            model_name=model_name,
            created_at=created_at,
            updated_at=updated_at,
            start_time=start_time,
            end_time=end_time,
            input_prompt_tokens_number=input_prompt_tokens_number,
            output_text_tokens_number=output_text_tokens_number,
            is_deleted=is_deleted,
            input_prompt=input_prompt,
            input_file_prompt=input_file_prompt,
            endpoint_type=endpoint_type,
            privacy_score=privacy_score,
            output_text=output_text,
            http_status_code=http_status_code,
            raw_request=raw_request,
            raw_response=raw_response,
            tag=tag,
            error=error,
            text_to_text_model_parameters=text_to_text_model_parameters,
            api_key=api_key,
        )

        api_projects_traces_create_json_body.additional_properties = d
        return api_projects_traces_create_json_body

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Dict, List, Type

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from typing_extensions import Any, TypedDict, TypeVar

T = TypeVar("T", bound="LeaderboardResponseLeaderboardItem")


class LeaderboardResponseLeaderboardItemDict(TypedDict):
    provider: str
    provider_slug: str
    provider_name: str
    avg_final_score: float
    avg_tokens_per_second: float
    avg_uptime: float
    avg_uptime_score: int
    avg_tokens_score: int
    pass


@_attrs_define
class LeaderboardResponseLeaderboardItem:
    """
    Attributes:
        provider (str):
        provider_slug (str):
        provider_name (str):
        avg_final_score (float):
        avg_tokens_per_second (float):
        avg_uptime (float):
        avg_uptime_score (int):
        avg_tokens_score (int):
    """

    provider: str
    provider_slug: str
    provider_name: str
    avg_final_score: float
    avg_tokens_per_second: float
    avg_uptime: float
    avg_uptime_score: int
    avg_tokens_score: int

    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        provider = self.provider

        provider_slug = self.provider_slug

        provider_name = self.provider_name

        avg_final_score = self.avg_final_score

        avg_tokens_per_second = self.avg_tokens_per_second

        avg_uptime = self.avg_uptime

        avg_uptime_score = self.avg_uptime_score

        avg_tokens_score = self.avg_tokens_score

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "provider": provider,
                "provider_slug": provider_slug,
                "provider_name": provider_name,
                "avg_final_score": avg_final_score,
                "avg_tokens_per_second": avg_tokens_per_second,
                "avg_uptime": avg_uptime,
                "avg_uptime_score": avg_uptime_score,
                "avg_tokens_score": avg_tokens_score,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        provider = d.pop("provider")

        provider_slug = d.pop("provider_slug")

        provider_name = d.pop("provider_name")

        avg_final_score = d.pop("avg_final_score")

        avg_tokens_per_second = d.pop("avg_tokens_per_second")

        avg_uptime = d.pop("avg_uptime")

        avg_uptime_score = d.pop("avg_uptime_score")

        avg_tokens_score = d.pop("avg_tokens_score")

        leaderboard_response_leaderboard_item = cls(
            provider=provider,
            provider_slug=provider_slug,
            provider_name=provider_name,
            avg_final_score=avg_final_score,
            avg_tokens_per_second=avg_tokens_per_second,
            avg_uptime=avg_uptime,
            avg_uptime_score=avg_uptime_score,
            avg_tokens_score=avg_tokens_score,
        )

        leaderboard_response_leaderboard_item.additional_properties = d
        return leaderboard_response_leaderboard_item

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
